Learn R Programming

gmvarkit (version 1.0.3)

aa_gmvarkit: gmvarkit: Estimate Gaussian Mixture Vector Autoregressive (GMVAR) model

Description

gmvarkit is a package for estimating Gaussian Mixture Vector Autoregressive (GMVAR) model. It provides functions for quantile residuals tests, graphical diagnostics, forecasting and simulations. Applying general linear constraints to the autoregressive parameters is supported.

Most of the functions documented are not exported, but for internal use only. The vignette is a good place to start.

Arguments