change_parametrization changes the parametrization of the given parameter
vector to change_to.
change_parametrization(
p,
M,
d,
params,
constraints = NULL,
change_to = c("intercept", "mean")
)a positive integer specifying the autoregressive order of the model.
a positive integer specifying the number of mixture components.
the number of time series in the system.
a real valued vector specifying the parameter values.
Should be size \(((M(pd^2+d+d(d+1)/2+1)-1)x1)\) and have form \(\theta\)\( = \)(\(\upsilon\)\(_{1}\), ...,\(\upsilon\)\(_{M}\), \(\alpha_{1},...,\alpha_{M-1}\)), where:
\(\upsilon\)\(_{m}\) \( = (\phi_{m,0},\)\(\phi\)\(_{m}\)\(,\sigma_{m})\)
\(\phi\)\(_{m}\)\( = (vec(A_{m,1}),...,vec(A_{m,p})\)
and \(\sigma_{m} = vech(\Omega_{m})\), m=1,...,M.
Should be size \(((M(d+d(d+1)/2+1)+q-1)x1)\) and have form \(\theta\)\( = (\phi_{1,0},...,\phi_{M,0},\)\(\psi\) \(,\sigma_{1},...,\sigma_{M},\alpha_{1},...,\alpha_{M-1})\), where:
\(\psi\) \((qx1)\) satisfies (\(\phi\)\(_{1}\)\(,...,\) \(\phi\)\(_{M}) =\) \(C \psi\). Here \(C\) is \((Mpd^2xq)\) constraint matrix.
Above, \(\phi_{m,0}\) is the intercept parameter, \(A_{m,i}\) denotes the \(i\):th coefficient matrix of the \(m\):th
mixture component, \(\Omega_{m}\) denotes the error term covariance matrix of the \(m\):th mixture component, and
\(\alpha_{m}\) is the mixing weight parameter.
If parametrization=="mean", just replace each \(\phi_{m,0}\) with regimewise mean \(\mu_{m}\).
\(vec()\) is vectorization operator that stacks columns of a given matrix into a vector. \(vech()\) stacks columns
of a given matrix from the principal diagonal downwards (including elements on the diagonal) into a vector.
The notation is in line with the cited article by Kalliovirta, Meitz and Saikkonen (2016) introducing the GMVAR model.
a size \((Mpd^2 x q)\) constraint matrix \(C\) specifying general linear constraints
to the autoregressive parameters. We consider constraints of form
(\(\phi\)\(_{1}\)\(,...,\)\(\phi\)\(_{M}) = \)\(C \psi\),
where \(\phi\)\(_{m}\)\( = (vec(A_{m,1}),...,vec(A_{m,p}) (pd^2 x 1), m=1,...,M\)
contains the coefficient matrices and \(\psi\) \((q x 1)\) contains the constrained parameters.
For example, to restrict the AR-parameters to be the same for all regimes, set \(C\)=
[I:...:I]' \((Mpd^2 x pd^2)\) where I = diag(p*d^2).
Ignore (or set to NULL) if linear constraints should not be employed.
either "intercept" or "mean" specifying to which parametrization it should be switched to.
If set to "intercept", it's assumed that params is mean-parametrized, and if set to "mean"
it's assumed that params is intercept-parametrized.
Returns parameter vector described in params, but with parametrization changed from intercept to mean
(when change_to==mean) or from mean to intercept (when change_to==intercept).
No argument checks!
Kalliovirta L., Meitz M. and Saikkonen P. 2016. Gaussian mixture vector autoregression. Journal of Econometrics, 192, 485-498.
Lutkepohl H. 2005. New Introduction to Multiple Time Series Analysis, Springer.