Learn R Programming

gmvarkit (version 1.0.1)

check_pMd: Check that p, M and d are correctly set

Description

check_pMd checks the argumens p, M and d.

Usage

check_pMd(p, M, d)

Arguments

p

a positive integer specifying the autoregressive degree of the model.

M

a positive integer specifying the number of mixture components.

d

number of time series in the system.

Value

Throws an error if something is wrong.