n_params calculates the number of parameters in the model.
n_params(
p,
M,
d,
model = c("GMVAR", "StMVAR", "G-StMVAR"),
constraints = NULL,
same_means = NULL,
structural_pars = NULL
)Returns the number of parameters in the parameter vector of the specified GMVAR, StMVAR, or G-StMVAR model.
a positive integer specifying the autoregressive order of the model.
a positive integer specifying the number of mixture components.
a size (2x1) integer vector specifying the number of GMVAR type components M1 in the
first element and StMVAR type components M2 in the second element. The total number of mixture components is M=M1+M2.
the number of time series in the system.
is "GMVAR", "StMVAR", or "G-StMVAR" model considered? In the G-StMVAR model, the first M1 components
are GMVAR type and the rest M2 components are StMVAR type.
a size \((Mpd^2 x q)\) constraint matrix \(C\) specifying general linear constraints
to the autoregressive parameters. We consider constraints of form
(\(\phi\)\(_{1}\)\(,...,\)\(\phi\)\(_{M}) = \)\(C \psi\),
where \(\phi\)\(_{m}\)\( = (vec(A_{m,1}),...,vec(A_{m,p}) (pd^2 x 1), m=1,...,M\),
contains the coefficient matrices and \(\psi\) \((q x 1)\) contains the related parameters.
For example, to restrict the AR-parameters to be the same for all regimes, set \(C\)=
[I:...:I]' \((Mpd^2 x pd^2)\) where I = diag(p*d^2).
Ignore (or set to NULL) if linear constraints should not be employed.
Restrict the mean parameters of some regimes to be the same? Provide a list of numeric vectors
such that each numeric vector contains the regimes that should share the common mean parameters. For instance, if
M=3, the argument list(1, 2:3) restricts the mean parameters of the second and third regime to be
the same but the first regime has freely estimated (unconditional) mean. Ignore or set to NULL if mean parameters
should not be restricted to be the same among any regimes. This constraint is available only for mean parametrized models;
that is, when parametrization="mean".
If NULL a reduced form model is considered. For structural model, should be a list containing
the following elements:
W - a \((dxd)\) matrix with its entries imposing constraints on \(W\): NA indicating that the element is
unconstrained, a positive value indicating strict positive sign constraint, a negative value indicating strict
negative sign constraint, and zero indicating that the element is constrained to zero.
C_lambda - a \((d(M-1) x r)\) constraint matrix that satisfies (\(\lambda\)\(_{2}\)\(,...,\)
\(\lambda\)\(_{M}) =\) \(C_{\lambda} \gamma\) where \(\gamma\) is the new \((r x 1)\)
parameter subject to which the model is estimated (similarly to AR parameter constraints). The entries of C_lambda
must be either positive or zero. Ignore (or set to NULL) if the eigenvalues \(\lambda_{mi}\)
should not be constrained.
See Virolainen (2022) for the conditions required to identify the shocks and for the B-matrix as well (it is \(W\) times a time-varying diagonal matrix with positive diagonal entries).
No argument checks!
Kalliovirta L., Meitz M. and Saikkonen P. 2016. Gaussian mixture vector autoregression. Journal of Econometrics, 192, 485-498.
Virolainen S. 2022. Structural Gaussian mixture vector autoregressive model with application to the asymmetric effects of monetary policy shocks. Unpublished working paper, available as arXiv:2007.04713.
Virolainen S. 2022. Gaussian and Student's t mixture vector autoregressive model with application to the asymmetric effects of monetary policy shocks in the Euro area. Unpublished working paper, available as arXiv:2109.13648.
@keywords internal