pick_Am picks the coefficient matrices \(A_{m,i} (i=1,..,p)\)
from the given parameter vector so that they are arranged in a 3D array with the
third dimension indicating each lag.
pick_Am(p, M, d, params, m, structural_pars = NULL)Returns a 3D array containing the coefficient matrices of the given component.
A coefficient matrix \(A_{m,i}\) can be obtained by choosing [, , i].
a positive integer specifying the autoregressive order of the model.
a positive integer specifying the number of mixture components.
a size (2x1) integer vector specifying the number of GMVAR type components M1 in the
first element and StMVAR type components M2 in the second element. The total number of mixture components is M=M1+M2.
number of time series in the system, i.e. the dimension.
a real valued vector specifying the parameter values.
Should be size \(((M(pd^2+d+d(d+1)/2+2)-M1-1)x1)\) and have the form \(\theta\)\( = \)(\(\upsilon\)\(_{1}\), ...,\(\upsilon\)\(_{M}\), \(\alpha_{1},...,\alpha_{M-1},\)\(\nu\)\()\), where
\(\upsilon\)\(_{m}\) \( = (\phi_{m,0},\)\(\phi\)\(_{m}\)\(,\sigma_{m})\)
\(\phi\)\(_{m}\)\( = (vec(A_{m,1}),...,vec(A_{m,p})\)
and \(\sigma_{m} = vech(\Omega_{m})\), m=1,...,M,
\(\nu\)\(=(\nu_{M1+1},...,\nu_{M})\)
\(M1\) is the number of GMVAR type regimes.
Should be size \(((M(d+d(d+1)/2+2)+q-M1-1)x1)\) and have the form \(\theta\)\( = (\phi_{1,0},...,\phi_{M,0},\)\(\psi\), \(\sigma_{1},...,\sigma_{M},\alpha_{1},...,\alpha_{M-1},\)\(\nu\)), where
\(\psi\) \((qx1)\) satisfies (\(\phi\)\(_{1}\)\(,...,\) \(\phi\)\(_{M}) =\) \(C \psi\) where \(C\) is a \((Mpd^2xq)\) constraint matrix.
Should have the form \(\theta\)\( = (\)\(\mu\),\(\psi\), \(\sigma_{1},...,\sigma_{M},\alpha_{1},...,\alpha_{M-1},\)\(\nu\)\()\), where
\(\mu\)\(= (\mu_{1},...,\mu_{g})\) where \(\mu_{i}\) is the mean parameter for group \(i\) and \(g\) is the number of groups.
If AR constraints are employed, \(\psi\) is as for constrained models, and if AR constraints are not employed, \(\psi\)\( = \) (\(\phi\)\(_{1}\)\(,...,\)\(\phi\)\(_{M})\).
Should have the form \(\theta\)\( = (\phi_{1,0},...,\phi_{M,0},\)\(\phi\)\(_{1},...,\)\(\phi\)\(_{M}, vec(W),\)\(\lambda\)\(_{2},...,\)\(\lambda\)\(_{M},\alpha_{1},...,\alpha_{M-1},\)\(\nu\)\()\), where
\(\lambda\)\(_{m}=(\lambda_{m1},...,\lambda_{md})\) contains the eigenvalues of the \(m\)th mixture component.
Replace \(\phi\)\(_{1}\)\(,...,\) \(\phi\)\(_{M}\) with \(\psi\) \((qx1)\) that satisfies (\(\phi\)\(_{1}\)\(,...,\) \(\phi\)\(_{M}) =\) \(C \psi\), as above.
Replace \((\phi_{1,0},...,\phi_{M,0})\) with \((\mu_{1},...,\mu_{g})\), as above.
Remove the zeros from \(vec(W)\) and make sure the other entries satisfy the sign constraints.
Replace \(\lambda\)\(_{2},...,\)\(\lambda\)\(_{M}\) with \(\gamma\) \((rx1)\) that satisfies (\(\lambda\)\(_{2}\)\(,...,\) \(\lambda\)\(_{M}) =\) \(C_{\lambda} \gamma\) where \(C_{\lambda}\) is a \((d(M-1) x r)\) constraint matrix.
Above, \(\phi_{m,0}\) is the intercept parameter, \(A_{m,i}\) denotes the \(i\)th coefficient matrix of the \(m\)th
mixture component, \(\Omega_{m}\) denotes the error term covariance matrix of the \(m\):th mixture component, and
\(\alpha_{m}\) is the mixing weight parameter. The \(W\) and \(\lambda_{mi}\) are structural parameters replacing the
error term covariance matrices (see Virolainen, 2022). If \(M=1\), \(\alpha_{m}\) and \(\lambda_{mi}\) are dropped.
If parametrization=="mean", just replace each \(\phi_{m,0}\) with regimewise mean \(\mu_{m}\).
\(vec()\) is vectorization operator that stacks columns of a given matrix into a vector. \(vech()\) stacks columns
of a given matrix from the principal diagonal downwards (including elements on the diagonal) into a vector.
In the GMVAR model, \(M1=M\) and \(\nu\) is dropped from the parameter vector. In the StMVAR model, \(M1=0\).
In the G-StMVAR model, the first M1 regimes are GMVAR type and the rest M2 regimes are StMVAR type.
In StMVAR and G-StMVAR models, the degrees of freedom parameters in \(\nu\) should be strictly larger than two.
The notation is similar to the cited literature.
which component?
If NULL a reduced form model is considered. For structural model, should be a list containing
the following elements:
W - a \((dxd)\) matrix with its entries imposing constraints on \(W\): NA indicating that the element is
unconstrained, a positive value indicating strict positive sign constraint, a negative value indicating strict
negative sign constraint, and zero indicating that the element is constrained to zero.
C_lambda - a \((d(M-1) x r)\) constraint matrix that satisfies (\(\lambda\)\(_{2}\)\(,...,\)
\(\lambda\)\(_{M}) =\) \(C_{\lambda} \gamma\) where \(\gamma\) is the new \((r x 1)\)
parameter subject to which the model is estimated (similarly to AR parameter constraints). The entries of C_lambda
must be either positive or zero. Ignore (or set to NULL) if the eigenvalues \(\lambda_{mi}\)
should not be constrained.
See Virolainen (2022) for the conditions required to identify the shocks and for the B-matrix as well (it is \(W\) times a time-varying diagonal matrix with positive diagonal entries).
No argument checks!
Does not support constrained parameter vectors.
Kalliovirta L., Meitz M. and Saikkonen P. 2016. Gaussian mixture vector autoregression. Journal of Econometrics, 192, 485-498.
Virolainen S. 2022. Structural Gaussian mixture vector autoregressive model with application to the asymmetric effects of monetary policy shocks. Unpublished working paper, available as arXiv:2007.04713.
Virolainen S. 2022. Gaussian and Student's t mixture vector autoregressive model with application to the asymmetric effects of monetary policy shocks in the Euro area. Unpublished working paper, available as arXiv:2109.13648.
@keywords internal