DEPRECATED! USE THE FUNCTION simulate.gsmvar INSTEAD!
simulateGMVAR simulates observations from a GMVAR
simulateGMVAR(
gmvar,
nsimu,
init_values = NULL,
ntimes = 1,
drop = TRUE,
seed = NULL,
girf_pars = NULL
)If drop==TRUE and ntimes==1 (default): $sample, $component, and $mixing_weights are matrices.
Otherwise, returns a list with...
$samplea size (nsim\( x d x \)ntimes) array containing the samples: the dimension [t, , ] is
the time index, the dimension [, d, ] indicates the marginal time series, and the dimension [, , i] indicates
the i:th set of simulations.
$componenta size (nsim\( x \)ntimes) matrix containing the information from which mixture component each
value was generated from.
$mixing_weightsa size (nsim\( x M x \)ntimes) array containing the mixing weights corresponding to the
sample: the dimension [t, , ] is the time index, the dimension [, m, ] indicates the regime, and the dimension
[, , i] indicates the i:th set of simulations.
object of class 'gmvar'
number of observations to be simulated.
a size \((pxd)\) matrix specifying the initial values, where d is the number
of time series in the system. The last row will be used as initial values for the first lag,
the second last row for second lag etc. If not specified, initial values will be drawn according to
mixture distribution specifed by the argument init_regimes.
how many sets of simulations should be performed?
if TRUE (default) then the components of the returned list are coerced to lower dimension if ntimes==1, i.e.,
$sample and $mixing_weights will be matrices, and $component will be vector.
set seed for the random number generator?
This argument is used internally in the estimation of generalized impulse response functions (see ?GIRF). You
should ignore it.
The argument ntimes is intended for forecasting: a GMVAR, StMVAR, or G-StMVAR process can be forecasted by simulating its possible future values.
One can easily perform a large number simulations and calculate the sample quantiles from the simulated values to obtain prediction
intervals (see the forecasting example).
Kalliovirta L., Meitz M. and Saikkonen P. 2016. Gaussian mixture vector autoregression. Journal of Econometrics, 192, 485-498.
Lütkepohl H. 2005. New Introduction to Multiple Time Series Analysis, Springer.
McElroy T. 2017. Computation of vector ARMA autocovariances. Statistics and Probability Letters, 124, 92-96.
Virolainen S. 2022. Structural Gaussian mixture vector autoregressive model with application to the asymmetric effects of monetary policy shocks. Unpublished working paper, available as arXiv:2007.04713.
Virolainen S. 2022. Gaussian and Student's t mixture vector autoregressive model with application to the asymmetric effects of monetary policy shocks in the Euro area. Unpublished working paper, available as arXiv:2109.13648.
simulate.gsmvar