Learn R Programming

gmvarkit (version 2.0.8)

stmvarpars_to_gstmvar: Transform a StMVAR (or G-StMVAR) model parameter vector to the corresponding G-StMVAR model parameter vector with the large df parameters removed.

Description

stmvarpars_to_gstmvar transforms a StMVAR (or G-StMVAR) model parameter vector to the corresponding G-StMVAR model parameter vector with the large df parameters removed.

Usage

stmvarpars_to_gstmvar(
  p,
  M,
  d,
  params,
  model = c("GMVAR", "StMVAR", "G-StMVAR"),
  constraints = NULL,
  same_means = NULL,
  structural_pars = NULL,
  maxdf = 100
)

Value

Returns a list with four elements: $params contains the corresponding G-StMVAR model parameter vector, $reg_order contains the permutation that was applied to the regimes (GMVAR type regimes first, and decreasing ordering by mixing weight parameters),

$M a vector of length two containing the number of GMVAR type regimes in the first element and the number of StMVAR type regimes in the second, $same_means constains the same_mean

constraints of the new model.

Arguments

p

a positive integer specifying the autoregressive order of the model.

M
For GMVAR and StMVAR models:

a positive integer specifying the number of mixture components.

For G-StMVAR models:

a size (2x1) integer vector specifying the number of GMVAR type components M1 in the first element and StMVAR type components M2 in the second element. The total number of mixture components is M=M1+M2.

params

a real valued vector specifying the parameter values.

For unconstrained models:

Should be size \(((M(pd^2+d+d(d+1)/2+2)-M1-1)x1)\) and have the form \(\theta\)\( = \)(\(\upsilon\)\(_{1}\), ...,\(\upsilon\)\(_{M}\), \(\alpha_{1},...,\alpha_{M-1},\)\(\nu\)\()\), where

  • \(\upsilon\)\(_{m}\) \( = (\phi_{m,0},\)\(\phi\)\(_{m}\)\(,\sigma_{m})\)

  • \(\phi\)\(_{m}\)\( = (vec(A_{m,1}),...,vec(A_{m,p})\)

  • and \(\sigma_{m} = vech(\Omega_{m})\), m=1,...,M,

  • \(\nu\)\(=(\nu_{M1+1},...,\nu_{M})\)

  • \(M1\) is the number of GMVAR type regimes.

For constrained models:

Should be size \(((M(d+d(d+1)/2+2)+q-M1-1)x1)\) and have the form \(\theta\)\( = (\phi_{1,0},...,\phi_{M,0},\)\(\psi\), \(\sigma_{1},...,\sigma_{M},\alpha_{1},...,\alpha_{M-1},\)\(\nu\)), where

  • \(\psi\) \((qx1)\) satisfies (\(\phi\)\(_{1}\)\(,...,\) \(\phi\)\(_{M}) =\) \(C \psi\) where \(C\) is a \((Mpd^2xq)\) constraint matrix.

For same_means models:

Should have the form \(\theta\)\( = (\)\(\mu\),\(\psi\), \(\sigma_{1},...,\sigma_{M},\alpha_{1},...,\alpha_{M-1},\)\(\nu\)\()\), where

  • \(\mu\)\(= (\mu_{1},...,\mu_{g})\) where \(\mu_{i}\) is the mean parameter for group \(i\) and \(g\) is the number of groups.

  • If AR constraints are employed, \(\psi\) is as for constrained models, and if AR constraints are not employed, \(\psi\)\( = \) (\(\phi\)\(_{1}\)\(,...,\)\(\phi\)\(_{M})\).

For structural models:

Should have the form \(\theta\)\( = (\phi_{1,0},...,\phi_{M,0},\)\(\phi\)\(_{1},...,\)\(\phi\)\(_{M}, vec(W),\)\(\lambda\)\(_{2},...,\)\(\lambda\)\(_{M},\alpha_{1},...,\alpha_{M-1},\)\(\nu\)\()\), where

  • \(\lambda\)\(_{m}=(\lambda_{m1},...,\lambda_{md})\) contains the eigenvalues of the \(m\)th mixture component.

If AR parameters are constrained:

Replace \(\phi\)\(_{1}\)\(,...,\) \(\phi\)\(_{M}\) with \(\psi\) \((qx1)\) that satisfies (\(\phi\)\(_{1}\)\(,...,\) \(\phi\)\(_{M}) =\) \(C \psi\), as above.

If same_means:

Replace \((\phi_{1,0},...,\phi_{M,0})\) with \((\mu_{1},...,\mu_{g})\), as above.

If \(W\) is constrained:

Remove the zeros from \(vec(W)\) and make sure the other entries satisfy the sign constraints.

If \(\lambda_{mi}\) are constrained:

Replace \(\lambda\)\(_{2},...,\)\(\lambda\)\(_{M}\) with \(\gamma\) \((rx1)\) that satisfies (\(\lambda\)\(_{2}\)\(,...,\) \(\lambda\)\(_{M}) =\) \(C_{\lambda} \gamma\) where \(C_{\lambda}\) is a \((d(M-1) x r)\) constraint matrix.

Above, \(\phi_{m,0}\) is the intercept parameter, \(A_{m,i}\) denotes the \(i\)th coefficient matrix of the \(m\)th mixture component, \(\Omega_{m}\) denotes the error term covariance matrix of the \(m\):th mixture component, and \(\alpha_{m}\) is the mixing weight parameter. The \(W\) and \(\lambda_{mi}\) are structural parameters replacing the error term covariance matrices (see Virolainen, 2022). If \(M=1\), \(\alpha_{m}\) and \(\lambda_{mi}\) are dropped. If parametrization=="mean", just replace each \(\phi_{m,0}\) with regimewise mean \(\mu_{m}\). \(vec()\) is vectorization operator that stacks columns of a given matrix into a vector. \(vech()\) stacks columns of a given matrix from the principal diagonal downwards (including elements on the diagonal) into a vector.

In the GMVAR model, \(M1=M\) and \(\nu\) is dropped from the parameter vector. In the StMVAR model, \(M1=0\). In the G-StMVAR model, the first M1 regimes are GMVAR type and the rest M2 regimes are StMVAR type. In StMVAR and G-StMVAR models, the degrees of freedom parameters in \(\nu\) should be strictly larger than two.

The notation is similar to the cited literature.

model

is "GMVAR", "StMVAR", or "G-StMVAR" model considered? In the G-StMVAR model, the first M1 components are GMVAR type and the rest M2 components are StMVAR type.

constraints

a size \((Mpd^2 x q)\) constraint matrix \(C\) specifying general linear constraints to the autoregressive parameters. We consider constraints of form (\(\phi\)\(_{1}\)\(,...,\)\(\phi\)\(_{M}) = \)\(C \psi\), where \(\phi\)\(_{m}\)\( = (vec(A_{m,1}),...,vec(A_{m,p}) (pd^2 x 1), m=1,...,M\), contains the coefficient matrices and \(\psi\) \((q x 1)\) contains the related parameters. For example, to restrict the AR-parameters to be the same for all regimes, set \(C\)= [I:...:I]' \((Mpd^2 x pd^2)\) where I = diag(p*d^2). Ignore (or set to NULL) if linear constraints should not be employed.

same_means

Restrict the mean parameters of some regimes to be the same? Provide a list of numeric vectors such that each numeric vector contains the regimes that should share the common mean parameters. For instance, if M=3, the argument list(1, 2:3) restricts the mean parameters of the second and third regime to be the same but the first regime has freely estimated (unconditional) mean. Ignore or set to NULL if mean parameters should not be restricted to be the same among any regimes. This constraint is available only for mean parametrized models; that is, when parametrization="mean".

structural_pars

If NULL a reduced form model is considered. For structural model, should be a list containing the following elements:

  • W - a \((dxd)\) matrix with its entries imposing constraints on \(W\): NA indicating that the element is unconstrained, a positive value indicating strict positive sign constraint, a negative value indicating strict negative sign constraint, and zero indicating that the element is constrained to zero.

  • C_lambda - a \((d(M-1) x r)\) constraint matrix that satisfies (\(\lambda\)\(_{2}\)\(,...,\) \(\lambda\)\(_{M}) =\) \(C_{\lambda} \gamma\) where \(\gamma\) is the new \((r x 1)\) parameter subject to which the model is estimated (similarly to AR parameter constraints). The entries of C_lambda must be either positive or zero. Ignore (or set to NULL) if the eigenvalues \(\lambda_{mi}\) should not be constrained.

See Virolainen (2022) for the conditions required to identify the shocks and for the B-matrix as well (it is \(W\) times a time-varying diagonal matrix with positive diagonal entries).

maxdf

regimes with degrees of freedom parameter value larger than this will be turned into GMVAR type.

Warning

No argument checks!