powered by
unvec reverse operator for vec().
unvec
vec()
unvec forms a square matrix from a vector of stacked colums, stacked by vec().
unvec(d, a)
number of rows the square matrix to be formed.
a size \((d^2x1)\) vector to be unvectorized into a \((dxd)\) matrix.
a matrix of size \((dxd)\).
No argument checks!