Learn R Programming

gmvarkit (version 1.0.1)

vech: Parsimonious vectorization operator for symmetric matrices.

Description

vech stacks colums of the given matrix from main diagonal downwards (including the main diagonal) to form a vector.

vech stacks colums of the given matrix from the principal diagonal downwards (including elements on the diagonal) to form a vector.

Usage

vech(A)

Arguments

A

a size \((dxd)\) symmmetric matrix to be vectorized parsimoniously.

Value

a vector of size \((d(d+1)/2x1)\).

Warning

No argument checks!