powered by
check_pMd checks the argumens p, M and d.
check_pMd
check_pMd(p, M, d)
a positive integer specifying the autoregressive degree of the model.
a positive integer specifying the number of mixture components.
number of time series in the system.
Throws an error if something is wrong.